(this["webpackJsonpstreamlit-image-crop"]=this["webpackJsonpstreamlit-image-crop"]||[]).push([[0],{17:function(e,r,t){e.exports=t(26)},26:function(e,r,t){"use strict";t.r(r);var a=t(7),n=t.n(a),o=t(14),s=t.n(o),p=t(5),c=t(0),i=t(1),l=t(2),g=t(12),m=t(16),u=t.n(m),d=(t(25),function(e){Object(i.a)(t,e);var r=Object(l.a)(t);function t(){var e;Object(c.a)(this,t);for(var a=arguments.length,o=new Array(a),s=0;s<a;s++)o[s]=arguments[s];return(e=r.call.apply(r,[this].concat(o))).state={},e.render=function(){var r=e.props.args.src,t=Object(p.a)(Object(p.a)({},e.props.args.crop),e.state),a=e.props.args.imageAlt,o=e.props.args.minWidth,s=e.props.args.minHeight,c=e.props.args.maxWidth,i=e.props.args.maxHeight,l=e.props.args.keepSelection,g=e.props.args.disabled,m=e.props.args.locked,d=e.props.args.ruleOfThirds,h=e.props.args.circularCrop;return n.a.createElement(u.a,{src:r,crop:t,imageAlt:a,minWidth:o,minHeight:s,maxWidth:c,maxHeight:i,keepSelection:l,disabled:g,locked:m,ruleOfThirds:d,circularCrop:h,onChange:function(r){return e.setState(r)},onComplete:e.onComplete})},e.onComplete=function(e,r){g.a.setComponentValue(r)},e}return t}(g.b)),h=Object(g.c)(d);s.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(h,null)),document.getElementById("root"))}},[[17,1,2]]]);
//# sourceMappingURL=main.9fe8165e.chunk.js.map