self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "d57cd48127d8c9f8a6263d8ab5bd0f24",
    "url": "./index.html"
  },
  {
    "revision": "e4d27476f5be776df50f",
    "url": "./static/css/2.1bce3852.chunk.css"
  },
  {
    "revision": "e4d27476f5be776df50f",
    "url": "./static/js/2.3a19b6c8.chunk.js"
  },
  {
    "revision": "9bf7777849ff7c0e7b1f4ddb70e6eb95",
    "url": "./static/js/2.3a19b6c8.chunk.js.LICENSE.txt"
  },
  {
    "revision": "3aade3e1afad7d8c3a27",
    "url": "./static/js/main.9fe8165e.chunk.js"
  },
  {
    "revision": "4c2909c6ac6424d3a449",
    "url": "./static/js/runtime-main.2af257da.js"
  }
]);